===============
Utility Scripts
===============

.. click:: ravenpy.cli:generate_grid_weights
   :prog: ravenpy generate-grid-weights
   :nested: full

.. click:: ravenpy.cli:aggregate_forcings_to_hrus
   :prog: ravenpy aggregate-forcings-to-hrus
   :nested: full

.. click:: ravenpy.cli:collect_subbasins_upstream_of_gauge
   :prog: ravenpy collect-subbasins-upstream-of-gauge
   :nested: full

.. click:: ravenpy.cli:generate_hrus_from_routing_product
   :prog: ravenpy generate-hrus-from-routing-product
   :nested: full
